diff --git a/core/modules/simpletest/src/AssertContentTrait.php b/core/modules/simpletest/src/AssertContentTrait.php
index 3cce705..1db8181 100644
--- a/core/modules/simpletest/src/AssertContentTrait.php
+++ b/core/modules/simpletest/src/AssertContentTrait.php
@@ -1192,8 +1192,8 @@ protected function assertOptionWithDrupalSelector($drupal_selector, $option, $me
   /**
    * Asserts that a select option in the current page does not exist.
    *
    * @param string $id
    *   ID of select field to assert.
    * @param string $option
    *   Option to assert.
    * @param string $message
@@ -1209,17 +1209,17 @@ protected function assertOptionWithDrupalSelector($drupal_selector, $option, $me
    * @return bool
    *   TRUE on pass, FALSE on fail.
    */
-  protected function assertNoOption($id, $option, $message = '', $group = 'Browser') {
-    $selects = $this->xpath('//select[@id=:id]', array(':id' => $id));
-    $options = $this->xpath('//select[@id=:id]//option[@value=:option]', array(':id' => $id, ':option' => $option));
-    return $this->assertTrue(isset($selects[0]) && !isset($options[0]), $message ? $message : SafeMarkup::format('Option @option for field @id does not exist.', array('@option' => $option, '@id' => $id)), $group);
+  protected function assertNoOption($name, $option, $message = '', $group = 'Browser') {
+    $selects = $this->xpath('//select[@name=:name]', array(':name' => $name));
+    $options = $this->xpath('//select[@name=:name]//option[@value=:option]', array(':name' => $name, ':option' => $option));
+    return $this->assertTrue(isset($selects[0]) && !isset($options[0]), $message ? $message : SafeMarkup::format('Option @option for field @name does not exist.', array('@option' => $option, '@name' => $name)), $group);
   }
 
   /**
    * Asserts that a select option in the current page is checked.
    *
    * @param string $id
    *   ID of select field to assert.
    * @param string $option
    *   Option to assert.
    * @param string $message
@@ -1234,12 +1234,11 @@ protected function assertNoOption($id, $option, $message = '', $group = 'Browser
    *
    * @return bool
    *   TRUE on pass, FALSE on fail.
-   *
-   * @todo $id is unusable. Replace with $name.
    */
-  protected function assertOptionSelected($id, $option, $message = '', $group = 'Browser') {
-    $elements = $this->xpath('//select[@id=:id]//option[@value=:option]', array(':id' => $id, ':option' => $option));
-    return $this->assertTrue(isset($elements[0]) && !empty($elements[0]['selected']), $message ? $message : SafeMarkup::format('Option @option for field @id is selected.', array('@option' => $option, '@id' => $id)), $group);
+  protected function assertOptionSelected($name, $option, $message = '', $group = 'Browser') {
+    $elements = $this->xpath('//select[@name=:name]//option[@value=:option]', array(':name' => $name, ':option' => $option));
+    debug($elements);
+    return $this->assertTrue(isset($elements[0]) && !empty($elements[0]['selected']), $message ? $message : SafeMarkup::format('Option @option for field @name is selected.', array('@option' => $option, '@name' => $name)), $group);
   }
 
   /**
@@ -1261,8 +1260,6 @@ protected function assertOptionSelected($id, $option, $message = '', $group = 'B
    *
    * @return bool
    *   TRUE on pass, FALSE on fail.
-   *
-   * @todo $id is unusable. Replace with $name.
    */
   protected function assertOptionSelectedWithDrupalSelector($drupal_selector, $option, $message = '', $group = 'Browser') {
     $elements = $this->xpath('//select[@data-drupal-selector=:data_drupal_selector]//option[@value=:option]', array(':data_drupal_selector' => $drupal_selector, ':option' => $option));
@@ -1272,8 +1269,8 @@ protected function assertOptionSelectedWithDrupalSelector($drupal_selector, $opt
   /**
    * Asserts that a select option in the current page is not checked.
    *
    * @param string $id
    *   ID of select field to assert.
    * @param string $option
    *   Option to assert.
    * @param string $message
@@ -1289,9 +1286,9 @@ protected function assertOptionSelectedWithDrupalSelector($drupal_selector, $opt
    * @return bool
    *   TRUE on pass, FALSE on fail.
    */
-  protected function assertNoOptionSelected($id, $option, $message = '', $group = 'Browser') {
-    $elements = $this->xpath('//select[@id=:id]//option[@value=:option]', array(':id' => $id, ':option' => $option));
-    return $this->assertTrue(isset($elements[0]) && empty($elements[0]['selected']), $message ? $message : SafeMarkup::format('Option @option for field @id is not selected.', array('@option' => $option, '@id' => $id)), $group);
+  protected function assertNoOptionSelected($name, $option, $message = '', $group = 'Browser') {
+    $elements = $this->xpath('//select[@name=:name]//option[@value=:option]', array(':name' => $name, ':option' => $option));
+    return $this->assertTrue(isset($elements[0]) && empty($elements[0]['selected']), $message ? $message : SafeMarkup::format('Option @option for field @name is not selected.', array('@option' => $option, '@name' => $name)), $group);
   }
 
   /**
@@ -1192,8 +1192,8 @@ protected function assertOptionWithDrupalSelector($drupal_selector, $option, $me
    * Asserts that a select option in the current page does not exist.
    *
-   * @param string $id
-   *   ID of select field to assert.
+   * @param string $name
+   *   Name of select field to assert.
    * @param string $option
    *   Option to assert.
@@ -1209,17 +1209,17 @@ protected function assertOptionWithDrupalSelector($drupal_selector, $option, $me
    * Asserts that a select option in the current page is checked.
    *
-   * @param string $id
-   *   ID of select field to assert.
+   * @param string $name
+   *   Name of select field to assert.
    * @param string $option
    *   Option to assert.
@@ -1272,8 +1269,8 @@ protected function assertOptionSelectedWithDrupalSelector($drupal_selector, $opt
    * Asserts that a select option in the current page is not checked.
    *
-   * @param string $id
-   *   ID of select field to assert.
+   * @param string $name
+   *   Name of select field to assert.
    * @param string $option
    *   Option to assert.
